@@ -3,7 +3,7 @@
 # svn2cl.sh - front end shell script for svn2cl.xsl, calls xsltproc
 #             with the correct parameters
 #
-# Copyright (C) 2005, 2006, 2007, 2008, 2009 Arthur de Jong.
+# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2013 Arthur de Jong
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -36,7 +36,7 @@ set -e
 set -u
 
 # svn2cl version
-VERSION="0.12"
+VERSION="0.14"
 
 # set default parameters
 PWD=`pwd`
@@ -56,11 +56,13 @@ AUTHORSFILE=""
 IGNORE_MESSAGE_STARTING=""
 TITLE="ChangeLog"
 REVISION_LINK="#r"
+TICKET_LINK=""
+TICKET_PREFIX="#"
 TMPFILES=""
 AWK="awk"
 
 # do command line checking
-prog=`basename $0`
+prog=`basename "$0"`
 while [ $# -gt 0 ]
 do
   case "$1" in
@@ -125,6 +127,22 @@ do
       REVISION_LINK=`echo "$1" | sed 's/^--[a-z-]*=//'`
       shift
       ;;
+    --ticket-link)
+      TICKET_LINK="$2"
+      shift 2 || { echo "$prog: option requires an argument -- $1";exit 1; }
+      ;;
+    --ticket-link=*)
+      TICKET_LINK=`echo "$1" | sed 's/^--[a-z-]*=//'`
+      shift
+      ;;
+    --ticket-prefix)
+      TICKET_PREFIX="$2"
+      shift 2 || { echo "$prog: option requires an argument -- $1";exit 1; }
+      ;;
+    --ticket-prefix=*)
+      TICKET_PREFIX=`echo "$1" | sed 's/^--[a-z-]*=//'`
+      shift
+      ;;
     --ignore-message-starting)
       IGNORE_MESSAGE_STARTING="$2"
       shift 2 || { echo "$prog: option requires an argument -- $1";exit 1; }
@@ -157,43 +175,40 @@ do
       OUTSTYLE="html"
       shift
       ;;
-    -r|--revision|--targets|--limit)
-      # add these as extra options to the command (with argument)
+    -r|--revision|-c|--change|--targets|-l|--limit)
+      # add these as extra options to the log command (with argument)
       arg=`echo "$2" | sed "s/'/'\"'\"'/g"`
       SVNLOGCMD="$SVNLOGCMD $1 '$arg'"
       shift 2 || { echo "$prog: option requires an argument -- $1";exit 1; }
       ;;
-    --username|--password|--config-dir)
-      # add these as extra options to the command (with argument)
+    --revision=*|--change=*|--targets=*|--limit=*)
+      # these are single argument versions of the above (with argument)
+      arg=`echo "$1" | sed "s/'/'\"'\"'/g"`
+      SVNLOGCMD="$SVNLOGCMD '$arg'"
+      shift
+      ;;
+    --username|--password|--config-dir|--config-option)
+      # add these as extra options to the log and info commands (with argument)
       arg=`echo "$2" | sed "s/'/'\"'\"'/g"`
       SVNLOGCMD="$SVNLOGCMD $1 '$arg'"
-      # also add to svn info command
       SVNINFOCMD="$SVNINFOCMD $1 '$arg'"
       shift 2 || { echo "$prog: option requires an argument -- $1";exit 1; }
       ;;
-    --revision=*|--targets=*|--limit=*)
-      # these are single argument versions of the above
+    --username=*|--password=*|--config-dir=*|--config-option=*)
+      # these are single argument versions of the above (with argument)
       arg=`echo "$1" | sed "s/'/'\"'\"'/g"`
       SVNLOGCMD="$SVNLOGCMD '$arg'"
-      shift
-      ;;
-    --username=*|--password=*|--config-dir=*)
-      # these are single argument versions of the above
-      arg=`echo "$1" | sed "s/'/'\"'\"'/g"`
-      SVNLOGCMD="$SVNLOGCMD '$arg'"
-      # also add to svn info command
       SVNINFOCMD="$SVNINFOCMD '$arg'"
       shift
       ;;
-    --stop-on-copy)
-      # add these as simple options
+    -g|--use-merge-history|--stop-on-copy)
+      # add these as simple options to the log command
       SVNLOGCMD="$SVNLOGCMD $1"
       shift
       ;;
-    --no-auth-cache|--non-interactive)
-      # add these as simple options
+    --no-auth-cache|--non-interactive|--trust-server-cert)
+      # add these as simple options to both the log and info commands
       SVNLOGCMD="$SVNLOGCMD $1"
-      # also add to svn info command
       SVNINFOCMD="$SVNINFOCMD $1"
       shift
       ;;
@@ -201,7 +216,7 @@ do
       echo "$prog $VERSION";
       echo "Written by Arthur de Jong."
       echo ""
-      echo "Copyright (C) 2005, 2006, 2007, 2008, 2009 Arthur de Jong."
+      echo "Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2013 Arthur de Jong."
       echo "This is free software; see the source for copying conditions.  There is NO"
       echo "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
       exit 0
@@ -210,8 +225,8 @@ do
       echo "Usage: $prog [OPTION]... [PATH]..."
       echo "Generate a ChangeLog from a subversion repository."
       echo ""
-      echo "  --strip-prefix=NAME  prefix to strip from all entries, defaults"
-      echo "                       path inside the repository"
+      echo "  --strip-prefix=NAME  prefix to strip from all entries, defaults path"
+      echo "                       inside the repository"
       echo "  --linelen=NUM        maximum length of an output line"
       echo "  --group-by-day       group changelog entries by day"
       echo "  --separate-daylogs   put a blank line between grouped by day entries"
@@ -222,6 +237,7 @@ do
       echo "  --reparagraph        rewrap lines inside a paragraph"
       echo "  --title=NAME         title used in html file"
       echo "  --revision-link=NAME link revision numbers in html output"
+      echo "  --ticket-link=NAME   change #foo strings to links"
       echo "  --ignore-message-starting=STRING"
       echo "                       ignore messages starting with the string"
       echo "  -o, --output=FILE    output to FILE instead of ChangeLog"
@@ -233,9 +249,10 @@ do
       echo "  -V, --version        output version information and exit"
       echo ""
       echo "PATH arguments and the following options are passed to the svn log"
-      echo "command: -r, --revision, --targets --stop-on-copy, --username,"
-      echo "--password, --no-auth-cache, --non-interactive, --config-dir and"
-      echo "--limit (see 'svn help log' for more information)."
+      echo "command: -r, --revision, -g, --use-merge-history, -c, --change,"
+      echo "--targets, --stop-on-copy, -l, --username, --password, --no-auth-cache,"
+      echo "--non-interactive, --trust-server-cert, --config-dir and --config-option"
+      echo "(see 'svn help log' for more information)."
       exit 0
       ;;
     -*)
@@ -321,6 +338,8 @@ eval "$SVNLOGCMD" | \
            --stringparam authorsfile "$AUTHORSFILE" \
            --stringparam title "$TITLE" \
            --stringparam revision-link "$REVISION_LINK" \
+           --stringparam ticket-link "$TICKET_LINK" \
+           --stringparam ticket-prefix "$TICKET_PREFIX" \
            --stringparam ignore-message-starting "$IGNORE_MESSAGE_STARTING" \
            --nowrite \
            --nomkdir \
